@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 from dataclasses import dataclass
 from typing import Sequence, Tuple
 
@@ -56,12 +54,6 @@ _FUNC_MAP = {
     "date": (functions.TruncDate, DateType),
 }
 
-if hasattr(functions, "ExtractIsoYear"):  # pragma: no branch
-    _FUNC_MAP.update(
-        {"iso_year": functions.ExtractIsoYear, "iso_week": functions.ExtractWeek}
-    )
-
-
 _FUNCTIONS = {
     DateTimeType: [
         "year",
@@ -88,7 +80,7 @@ def get_model_name(model, sep="."):
 
 @dataclass
 class OrmBoundField:
-    field: OrmBaseField
+    field: "OrmBaseField"
     full_path: Sequence[str]
     pretty_path: Sequence[str]
     queryset_path: str = None
