@@ -11,7 +11,15 @@ settings.configure(
         "data_browser",
     ],
     DATABASES={
-        "default": {"ENGINE": "django.db.backends.sqlite3", "NAME": "db.sqlite3"}
+        "default": {"ENGINE": "django.db.backends.sqlite3", "NAME": "db.sqlite3"},
+        "xdefault": {
+            "ENGINE": "django.db.backends.postgresql",
+            "NAME": "data_browser",
+            "USER": "eligible",
+            "PASSWORD": "g7W987XRmtO5VBbC0jkj",
+            "HOST": "localhost",
+            "PORT": 5432,
+        },
     },
     ROOT_URLCONF="tests.urls",
     MIDDLEWARE=[
